# Reverse Engineering Neural Networks (RENN)

![build](https://github.com/google-research/reverse-engineering-neural-networks/workflows/build/badge.svg)

`renn` is a collection of research code for reverse engineering neural networks, with a focus on using tools from dynamical systems theory.

## Warning
**This repo is currently under active development. Consider it an alpha release. Better documentation, tests, and more are coming! (est. Q4 2020)**

## Contributing

### Formatting checks

Formatting checks are done via yapf, enabled automatically by 'pre-commit'.
To get these up and running:

#### yapf:

1. pip install yapf

#### pre-commit:

1. pip install pre-commit
2. Run `pre-commit install`
